@@ -1,5 +1,5 @@
 from .test_dao import TestDao, TestDaoFactory
-from .utils import evaluate_experiment_agg, evaluate_experiment_by_unit
+from .utils import evaluate_experiment_agg, evaluate_experiment_simple_agg, evaluate_experiment_by_unit
 from .utils import assert_experiment, assert_metrics, assert_checks, assert_exposures
 from .utils import check_docstring
 from .test_data import TestData
